const webpack = require('webpack')
const path = require('path')

const HtmlWebpackPlugin = require('html-webpack-plugin')

// 引入dev-server配置文件
var serverConfig = require('./config/config.server.js');

// 引入接口代理配置文件
const proxyConfig = require('./config/config.proxy.js'); 

module.exports = {
  target: 'web',
  devServer: {
    historyApiFallback: true,
    disableHostCheck: true,
    hot: false,
    inline: true,
    contentBase: "./src",
    port: serverConfig.port,
    host: serverConfig.host,
    proxy: proxyConfig
  },
  entry: './src/index.js',
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: '[name].js',
    publicPath: '/',
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        use: ['babel-loader', 'eslint-loader'],
        exclude: [/node_modules/],
      },
      {
        test: /\.css$/,
        use: [ 'style-loader', 'css-loader' ],
      },
      {
        test: /\.less$/,
        use: [ 'style-loader', 'css-loader', { loader: 'less-loader', options: { javascriptEnabled: true } } ],
      },
      {
        test: /\.(png|jpg|gif)$/,
        use: [
          {
            loader: 'url-loader',
            options: {
              limit: 8192,
            }
          }
        ]
      }
    ],
  },
  mode: 'development',
  devtool: 'cheap-module-source-map',
  plugins: [
    // new webpack.DefinePlugin({
    //     'process.env': {
    //         'NODE_ENV': '"production"'
    //     }
    // })
    new HtmlWebpackPlugin(
      {
        filename: 'index.html',
        template: './src/index.html'
      }
    ),
  ]
};